summaryrefslogtreecommitdiffstats
path: root/lskat/lskat/lskat.h
diff options
context:
space:
mode:
Diffstat (limited to 'lskat/lskat/lskat.h')
-rw-r--r--lskat/lskat/lskat.h30
1 files changed, 15 insertions, 15 deletions
diff --git a/lskat/lskat/lskat.h b/lskat/lskat/lskat.h
index 1c29845c..83882358 100644
--- a/lskat/lskat/lskat.h
+++ b/lskat/lskat/lskat.h
@@ -56,17 +56,17 @@ class LSkatView;
* window and reads the config file as well as providing a menubar, toolbar
* and statusbar. An instance of LSkatView creates your center view, which is connected
* to the window's Doc object.
* LSkatApp reimplements the methods that KMainWindow provides for main window handling and supports
* full session management as well as keyboard accelerator configuration by using KAccel.
* @see KMainWindow
* @see TDEApplication
* @see TDEConfig
- * @see KAccel
+ * @see TDEAccel
*
* @author Source Framework Automatically Generated by KDevelop, (c) The KDevelop Team.
* @version KDevelop version 0.4 code generation
*/
-class LSkatApp : public KMainWindow
+class LSkatApp : public TDEMainWindow
{
Q_OBJECT
@@ -86,7 +86,7 @@ class LSkatApp : public KMainWindow
void disableAction(const char *);
/** add a opened file to the recent file list and update recent_file_menu
*/
/** returns a pointer to the current document connected to the KMainWindow instance and is used by
* the View class to access the document object's methods
*/
LSkatDoc *getDocument() const;
@@ -118,31 +118,31 @@ class LSkatApp : public KMainWindow
* @see initView();
*/
void initDocument();
/** creates the centerwidget of the KMainWindow instance and sets it as the view
*/
void initView();
/** queryClose is called by KMainWindow on each closeEvent of a window. Against the
* default implementation (only returns true), this calles saveModified() on the document object to ask if the document shall
* be saved if Modified; on cancel the closeEvent is rejected.
- * @see KMainWindow#queryClose
- * @see KMainWindow#closeEvent
+ * @see TDEMainWindow#queryClose
+ * @see TDEMainWindow#closeEvent
*/
virtual bool queryClose();
/** queryExit is called by KMainWindow when the last window of the application is going to be closed during the closeEvent().
* Against the default implementation that just returns true, this calls saveOptions() to save the settings of the last window's
* properties.
- * @see KMainWindow#queryExit
- * @see KMainWindow#closeEvent
+ * @see TDEMainWindow#queryExit
+ * @see TDEMainWindow#closeEvent
*/
virtual bool queryExit();
/** saves the window properties for each open window during session end to the session config file, including saving the currently
* opened file by a temporary filename provided by TDEApplication.
- * @see KMainWindow#saveProperties
+ * @see TDEMainWindow#saveProperties
*/
virtual void saveProperties(TDEConfig *_cfg);
/** reads the session config file and restores the application's state including the last opened files and documents by reading the
* temporary files saved by saveProperties()
- * @see KMainWindow#readProperties
+ * @see TDEMainWindow#readProperties
*/
virtual void readProperties(TDEConfig *_cfg);
@@ -56,17 +56,17 @@ class LSkatView;
* and statusbar. An instance of LSkatView creates your center view, which is connected
* to the window's Doc object.
- * LSkatApp reimplements the methods that KMainWindow provides for main window handling and supports
- * full session management as well as keyboard accelerator configuration by using KAccel.
- * @see KMainWindow
+ * LSkatApp reimplements the methods that TDEMainWindow provides for main window handling and supports
+ * full session management as well as keyboard accelerator configuration by using TDEAccel.
+ * @see TDEMainWindow
* @see TDEApplication
* @see TDEConfig
@@ -86,7 +86,7 @@ class LSkatApp : public KMainWindow
/** add a opened file to the recent file list and update recent_file_menu
*/
- /** returns a pointer to the current document connected to the KMainWindow instance and is used by
+ /** returns a pointer to the current document connected to the TDEMainWindow instance and is used by
* the View class to access the document object's methods
*/
@@ -118,31 +118,31 @@ class LSkatApp : public KMainWindow
*/
void initDocument();
- /** creates the centerwidget of the KMainWindow instance and sets it as the view
+ /** creates the centerwidget of the TDEMainWindow instance and sets it as the view
*/
void initView();
@@ -118,31 +118,31 @@ class LSkatApp : public KMainWindow
*/
void initView();
- /** queryClose is called by KMainWindow on each closeEvent of a window. Against the
+ /** queryClose is called by TDEMainWindow on each closeEvent of a window. Against the
* default implementation (only returns true), this calles saveModified() on the document object to ask if the document shall
* be saved if Modified; on cancel the closeEvent is rejected.
@@ -118,31 +118,31 @@ class LSkatApp : public KMainWindow
*/
virtual bool queryClose();
- /** queryExit is called by KMainWindow when the last window of the application is going to be closed during the closeEvent().
+ /** queryExit is called by TDEMainWindow when the last window of the application is going to be closed during the closeEvent().
* Against the default implementation that just returns true, this calls saveOptions() to save the settings of the last window's
* properties.